# StenoBee
>

>
![StenoBee](https://github.com/Tink-Bell/StenoBee/assets/143440063/d6d22592-c82b-4ab7-bbef-98ead1f0aaa6)
>

>
Plover plugin for Spelling Based Stenography
>
Created by Tink & Emily & Kaoffie
>
With lots of help from, Jen and paulfioravanti :)
>

>

>
![ezgif-2-9a548ef0d5](https://github.com/Tink-Bell/StenoBee/assets/143440063/1bc790b8-b83d-4e1a-a4f7-52ff6f215e7b)
>

>

>
StenoBee, is a spelling based, orderless Steno theory for Plover.
>

>
![Plover_trans](https://github.com/Tink-Bell/StenoBee/assets/143440063/a63cce07-d8e1-4d6b-bf80-89ff05a1cd79)
>

>
Some key points about Stenobee
>
1) Originally made to avoid having issues with dialect differences in vowel sounds
>
2) By Using the custom Dictionary creation tools, the dictionary can be based solely on your own personal lexicon.
>
3) The default dictionary is made from 445k words (13k unique words), of sample text from myself over 3-4 years of my discord messages.
>

>

>
What is StenoBee Good for
>
1) It's great at being opitimized for how you speak, using the python scripts to build the dictionary.
>
2) It's great at encoding long phrases into single strokes
>

>

>
What is StenoBee is bad at.
>
1) Captioning, and court reporting work, since the orderless non phonetic nature of it actively makes transcription related work harder.
>
2) Small words are often made longer with suffixes if they are less common, as they are more likely to need disambiguation.
>

>

>
![newlayout](https://github.com/Tink-Bell/StenoBee/assets/143440063/64458a5f-b230-46f6-a254-20d46189f56a)
>

>
![Number Mapping](https://github.com/Tink-Bell/StenoBee/assets/143440063/5d05e90d-5b49-402d-a0f1-a75bd1e15633)
>

>
![symb](https://github.com/Tink-Bell/StenoBee/assets/143440063/0d6782ad-ca47-4e3f-9bf3-9ffa05324232)
>

>
![STENOBEE_example](https://github.com/Tink-Bell/StenoBee/assets/143440063/d35d6ba6-cf48-4928-ad1b-6ac3a1719c6b)
>

>
![Screenshot from 2023-09-22 10-50-00](https://github.com/Tink-Bell/StenoBee/assets/143440063/87f15a32-9bff-4a1b-8e67-99054ec21b00)
>

>
![examples](https://github.com/Tink-Bell/StenoBee/assets/143440063/a28a3695-86d0-4463-a5e6-3cf9dd6050b4)
>

